@@ -244,7 +244,7 @@ nnetar <- function(y, p, P=1, size, repeats=20, xreg=NULL, lambda=NULL, model=NU
       P <- 0
     } else {
       if (missing(p)) {
-        if (n >= 2 * m) {
+        if (n > 2 * m) {
           x.sa <- seasadj(mstl(na.interp(xx)))
         } else {
           x.sa <- na.interp(xx)
